#
# spec file for package mingw64-filesystem
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Tumbleweed
%if %suse_version >= 1550
%define _rpmlintdir /opt/testing/share/rpmlint
%else
%define _rpmlintdir /opt/testing/share/rpmlint/mini
%endif

%define debug_package %{nil}
%if %{undefined _distconfdir}
%define _distconfdir %{_sysconfdir}
%endif
%if %{undefined _rpmmacrodir}
%define _rpmmacrodir %{_sysconfdir}/rpm
%endif
Name:           mingw64-filesystem
Version:        20250515
Release:        1.1
Summary:        MinGW base filesystem and environment
License:        GPL-2.0-or-later
Group:          Development/Libraries/Other
URL:            http://hg.et.redhat.com/misc/fedora-mingw--devel/
Source0:        COPYING
Source1:        macros.mingw64
Source2:        mingw64.sh
Source3:        mingw64-find-debuginfo.sh
Source4:        mingw64-find-requires.sh
Source5:        mingw64-find-provides.sh
Source6:        mingw64-scripts.sh
Source7:        mingw64-rpmlintrc
Source8:        mingw64-install-post.sh
Source9:        mingw64-find-lang.sh
Source10:       languages
Source11:       languages.man
Source15:       mingw64-filesystem-rpmlintrc
Source16:       mingw-objdump-srcfiles
Source17:       mingw64_binaries.attr
Source19:       mingw64_config.attr
Source20:       mingw64_libs.attr
Source21:       mingw64_pkgconfig.attr
# add excluded system libraries to mingw64-find-requires.sh
# TODO: The following provides could be removed after all packages has been rebuild
Provides:       mingw64(bcrypt.dll)
Provides:       mingw64(dbghelp.dll)
Provides:       mingw64(mpr.dll)
Provides:       mingw64(odbccp32.dll)
Provides:       mingw64(userenv.dll)
Provides:       mingw64(uxtheme.dll)
# TODO: The available DLL's can be identified by the
# available import libraries of the mingw64-runtime package.
# needed by mingw64-libqt5-qtbase
Provides:       mingw64(d2d1.dll)
Provides:       mingw64(d3d11.dll)
Provides:       mingw64(d3d12.dll)
Provides:       mingw64(dcomp.dll)
Provides:       mingw64(dwrite.dll)
Provides:       mingw64(dxgi.dll)
Provides:       mingw64(ncrypt.dll)
Provides:       mingw64(wtsapi32.dll)
Requires:       coreutils
Requires:       findutils
Requires:       gawk
Requires:       grep
Requires:       mingw64-cross-binutils-utils
Requires:       mingw64-cross-pkgconf-utils
Requires:       python3
Requires:       rpm
Requires:       rpmlint-mini
Requires:       sed
BuildArch:      noarch
#!BuildIgnore: post-build-checks

%description
This package contains the base filesystem layout, RPM macros and
environment for all MinGW packages.

This environment is maintained by the Fedora MinGW SIG at:

  http://fedoraproject.org/wiki/SIGs/MinGW

%prep
%setup -q -c -T
cp %{SOURCE0} COPYING
sed 's/@VERSION@/%{version}/' < %{SOURCE4} > mingw64-find-requires.sh

%build
# nothing

%install
mkdir -p %{buildroot}

mkdir -p %{buildroot}%{_prefix}/lib

mkdir -p %{buildroot}%{_libexecdir}
install -m 755 %{SOURCE6} %{buildroot}%{_libexecdir}/mingw64-scripts

# this is already provided by _mingw64_create_macro_links
# but including macros.mingw64 results into an unknown failure
mkdir -p %{buildroot}%{_bindir}
pushd %{buildroot}%{_bindir}
for i in mingw64-configure mingw64-make mingw64-gdb; do
  ln -s %{_libexecdir}/mingw64-scripts $i
done
popd

mkdir -p %{buildroot}%{_distconfdir}/profile.d
install -m 644 %{SOURCE2} %{buildroot}%{_distconfdir}/profile.d/

mkdir -p %{buildroot}%{_rpmmacrodir}
install -m 644 %{SOURCE1} %{buildroot}%{_rpmmacrodir}/macros.mingw64

mkdir -p %{buildroot}%_rpmlintdir
# tumbleweed
%if %suse_version >= 1550
# convert to toml file format, which seems to be required
sed "s,addFilter *(\",     ',g;s#\")#',#g" %{SOURCE7} | gawk 'BEGIN { print "Filters = ["} { print $0 } END { print "]"}' > %{SOURCE7}.toml
install -m 644 %{SOURCE7}.toml %{buildroot}%_rpmlintdir/mingw64.toml
%else
install -m 644 %{SOURCE7} %{buildroot}%_rpmlintdir/mingw64-rpmlint.config
%endif

mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32

# GCC requires these directories, even though they contain links
# to binaries which are also installed in /usr/bin etc.  These
# contain native binaries.
mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32/bin
mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32/lib

# The MinGW system root which will contain Windows native binaries
# and Windows-specific header files, pkgconfig, etc.
mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32/sys-root/mingw
mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32/sys-root/mingw/bin
mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32/sys-root/mingw/include
mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32/sys-root/mingw/include/sys
mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32/sys-root/mingw/lib
mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32/sys-root/mingw/lib/cmake
mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32/sys-root/mingw/lib/pkgconfig
mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32/sys-root/mingw/share
mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32/sys-root/mingw/share/aclocal
mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32/sys-root/mingw/share/pkgconfig
mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32/sys-root/mingw/var
mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32/sys-root/mingw%{_localstatedir}/lib
mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32/sys-root/mingw%{_localstatedir}/lib/rpm-state
mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32/sys-root/mingw%{_localstatedir}/lib/rpm-state/gconf

(cd %{buildroot}%{_prefix}/x86_64-w64-mingw32/sys-root && ln -s mingw x86_64-w64-mingw32)

# Let programs locate their plugins relative to the executable without using
# upward movement ("..") in those packages, cf. libdbi, libenchant.
#
mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32/sys-root/mingw/bin/lib
ln -s ../../lib "%buildroot/%_prefix/x86_64-w64-mingw32/sys-root/mingw/bin/lib/x86_64-pc"

mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32/sys-root/mingw/share
mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32/sys-root/mingw/share/doc
mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32/sys-root/mingw/share/info
mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32/sys-root/mingw/share/man
mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32/sys-root/mingw/share/man/man{1,2,3,4,5,6,7,8,9,n}

# NB. NOT _libdir
mkdir -p %{buildroot}%{_rpmconfigdir}
install -m 0755 %{SOURCE3} %{buildroot}%{_rpmconfigdir}
install -m 0755 %{SOURCE4} %{buildroot}%{_rpmconfigdir}
install -m 0755 %{SOURCE5} %{buildroot}%{_rpmconfigdir}
install -m 0755 %{SOURCE8} %{buildroot}%{_rpmconfigdir}
install -m 0755 %{SOURCE9} %{buildroot}%{_rpmconfigdir}
# dependency generator support
mkdir -p %{buildroot}%{_fileattrsdir}
install -m 0644 %{SOURCE17} %{buildroot}%{_fileattrsdir}
install -m 0644 %{SOURCE19} %{buildroot}%{_fileattrsdir}
install -m 0644 %{SOURCE20} %{buildroot}%{_fileattrsdir}
install -m 0644 %{SOURCE21} %{buildroot}%{_fileattrsdir}

# Create the locale directories:
while read LANG ; do
  mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32/sys-root/mingw/share/locale/$LANG/LC_MESSAGES
  mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32/sys-root/mingw/share/help/$LANG
done < %{SOURCE10}
# Create the locale directories for man:
while read LANG ; do
  mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32/sys-root/mingw/share/man/$LANG
  for sec in 1 2 3 4 5 6 7 8 9 n; do
    mkdir -p %{buildroot}%{_prefix}/x86_64-w64-mingw32/sys-root/mingw/share/man/$LANG/man$sec
  done
done < %{SOURCE11}

install -m 0755 %{SOURCE16} %{buildroot}%{_bindir}/x86_64-w64-mingw32-objdump-srcfiles

%files
%license COPYING
%{_rpmmacrodir}/macros.mingw64
%if %{undefined _distconfdir}
%config %{_sysconfdir}/profile.d/mingw64.sh
%else
%{_distconfdir}/profile.d/mingw64.sh
%endif
%if %suse_version >= 1550
%_rpmlintdir/mingw64.toml
%else
%_rpmlintdir/mingw64-rpmlint.config
%endif

%{_fileattrsdir}/mingw64*.attr
%{_bindir}/mingw64-*
%{_bindir}/x86_64-w64-mingw32-*
%{_libexecdir}/mingw64-scripts
%{_prefix}/x86_64-w64-mingw32/
%{_rpmconfigdir}/mingw64-*
%dir %{_prefix}/x86_64-w64-mingw32/sys-root/mingw/lib/cmake

%changelog
* Tue May 13 2025 Michal Suchanek <msuchanek@suse.de>
- Update to version 20250515
- Avoid spurious requires when using ucrt runtime (boo#1243096).
* Mon May 12 2025 Ralf Habacker <ralf.habacker@freenet.de>
- Update to version 20250512
- Hide the rpmlint warning via an unspecified group, as this has
  been optional since 2020 according to
  https://news.opensuse.org/2020/11/23/news-in-opensuse-packaging/#group-tag
* Tue Apr 22 2025 Ralf Habacker <ralf.habacker@freenet.de>
- Update to version 20250422
- mingw64.macros:
  * Add support for creating debug info packages for native packages
    in addition to those for Windows
- mingw64-install-post.sh:
  * Fix warning: warning: egrep is obsolescent; using grep -E
* Fri Feb 21 2025 Ralf Habacker <ralf.habacker@freenet.de>
- Update to version 20250221
  * Reverse the use of the current directory in %%_mingw64_debug_package;
    it prevents the building of many packages
* Thu Feb 20 2025 Ralf Habacker <ralf.habacker@freenet.de>
- Update to version 20250220
- mingw64.macros:
  * Add parameter '-N' to %%_mingw64_debug_package
    to be able to specify a full package name, which is required
    by the wine package
  * Add parameter '-C' to %%_mingw64_debug_package to be able
    to add a Conflicts tag, which is required
    by the wine package
  * In %%_mingw64_debug_package use actual directory to find
    the debuginfo files list to be in sync with the native
    debug package
* Sun Feb  2 2025 Ralf Habacker <ralf.habacker@freenet.de>
- Syntax fix in %%_mingw64_debug_package on Leap 15.x
* Sun Feb  2 2025 Ralf Habacker <ralf.habacker@freenet.de>
- Update version to 202500202
- Extend mingw64-find-debuginfo.sh:
  * Merging debug source package into debug info package is now
    provided with option '--merge-debug-source-package'
  * Add option '--no-debug-source-package' to skip building of
    debug source package used by wine package
  * Add option '--src-root-dir' to specify a custom directory
    for installing debug source files
- mingw64.macros: Add parameter '-e' to %%_mingw64_debug_package
  to exclude BuildArch: noarch used by wine package
* Mon Nov 18 2024 Ralf Habacker <ralf.habacker@freenet.de>
- Update version to 20241118
- Speed up the collection of source files for the creation of debug
  packages by using multiple concurrent processes (boo1202431)
* Sat Aug  3 2024 Ralf Habacker <ralf.habacker@freenet.de>
- Update version to 20240803
- Do not block adding native debug package when using
  mingw64-cross-filesystem (boo#1228778)
* Wed Jul 31 2024 Ralf Habacker <ralf.habacker@freenet.de>
- Update version to 20240801
- Add missing man language ca@valencia required by KDE Frameworks 5.103
* Mon Jun 12 2023 Ralf Habacker <ralf.habacker@freenet.de>
- Update to 20230614
  * Fix unwanted dump of rpm option when using mingw64-* command
    line wrapper (boo#1212239)
* Tue Mar 28 2023 Ralf Habacker <ralf.habacker@freenet.de>
- Update to version 20230401
  * Drop cmake support files as they are now located in the
    mingw64-cross-cmake (boo#1209611)
* Fri Mar 17 2023 Ralf Habacker <ralf.habacker@freenet.de>
- In cmake macros, avoid changing the current directory
  to avoid build errors in packages that use multiple
  build systems such as mingw64-zlib
* Thu Feb 16 2023 Ralf Habacker <ralf.habacker@freenet.de>
- Update to version 20230309
  * Let cmake macros be based on associated macros from macros.cmake
  * Add support to define a custom rpm macro when running mingw64
    related shell scripts, see mingw64-scripts.sh for details
  * Drop using external dependency generator (boo#1175587)
  * Add mingw64_*.attr files to support actual used dependency generator
  * Fix bug that rpm does not use attribute file for cmake by renaming
    to mingw64_cmake.attr (rpm does not like '-' in those file name
    and keys inside)
  * Extend mingw64_cmake.attr to find cmake support files in
    share subdirectory as required for example by mingw64-dlfcn-win32
  * Print deprecated message when using %%_mingw64_makeinstall or
    %%__mingw64_cmake
  * Reduce some differences to mingw32 in changes and other files,
    which are mostly indentions, hours, trailing '/', variable
    definition rows - make it easier to compare
* Mon Nov 14 2022 Ralf Habacker <ralf.habacker@freenet.de>
- Update to version 20221115
  * Fix doc in macros.mingw64 how to define macro _mingw64_find_requires_exclude
  * Change dependency to mingw64-cross-binutils-utils and
    mingw64-cross-pkgconf-utils to avoid cyclic dependencies (boo#1204985)
* Mon Aug 29 2022 Ralf Habacker <ralf.habacker@freenet.de>
- Fix generating invalid source file path when scanning binaries
  (boo#1202865)
* Fri Aug 26 2022 Ralf Habacker <ralf.habacker@freenet.de>
- Update to 20220826
- Speed up objdump scanning binaries for source files (boo#1202431)
* Wed Aug 10 2022 Jan Engelhardt <jengelh@inai.de>
- Drop dependency on breakpad, since we now have our own
  mingw-objdump-srcfiles.
* Thu Jul 28 2022 Ralf Habacker <ralf.habacker@freenet.de>
- Update to 20220805
- Fix for generating the source file list for the debug package (boo#1201107).
  * Added the script 'mingw-objdump-srcfiles' to determine the
    source files used by the package in question.
  * The gawk script is based on a perl script from jengelh, which was
    not adopted due to an additional runtime dependency
  * With this change, *.sym files are no longer included in generated
    debug packages
  * The now obsolete runtime dependency to mingw64-cross-breakpad-tools
    has been removed
- Exclude 'mlang.dll' and other dll's from automatic runtime library
  detection required for win_iconv and libqt5 packages
- Fix spelling in *.changes
* Thu Jul 28 2022 Ralf Habacker <ralf.habacker@freenet.de>
- Add 'arch-independent-package-contains-binary-or-object' filter also
  for static libraries (boo#1201173)
- When scanning libraries exclude non real dll file names e.g. '%%s.dll'
* Mon Jul 25 2022 Ralf Habacker <ralf.habacker@freenet.de>
- Add missing runtime dependencies (boo#1188144)
- Use newer $host-pkgconf
- Fix using undefined STRINGS env variable
* Wed Jul 20 2022 Ralf Habacker <ralf.habacker@freenet.de>
- Update to 20220801
- Fetch real used shared library name from import libraries to avoid
  file name generation errors, for example with mingw64-glib2
- Scan all archives for shared library names as packages may not use
  the default import library extension
* Tue Jul 12 2022 Ralf Habacker <ralf.habacker@freenet.de>
- Fix finding qm files for KDE Frameworks >= 5.76 (taken from rpm-4.14.1)
* Sun Jun  5 2022 Ralf Habacker <ralf.habacker@freenet.de>
- Update to 20220620
- Add more provides required by libqt5 related packages
- Add optional support for excluding runtime DLL dependencies to avoid
  rebuilding the whole project, see macro %%_mingw64_find_requires_exclude
  in macros.mingw64 for details
* Mon May 23 2022 Ralf Habacker <ralf.habacker@freenet.de>
- Update to 20220524
- On finding provides and requirements do not generate temporary
  files in the global temporary directory (boo#1182356)
- Add optional support to add runtime dependencies for import
  libraries, see macros.mingw64 for details (boo#1194430)
- Fix warning 'file format not recognized' in mingw64-find-requires.sh
  when parsing xxx-config files
* Thu Dec  2 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Change all version comparisons for Tumbleweed to >= 1550 (instead
  of == 1550). Anything in Tumbleweed counts for current Tumbleweed
  plus future CODE branches. Additionally, the Tumbleweed
  suse_version code is not chiseled in stone.
* Tue Sep 14 2021 Ralf Habacker <ralf.habacker@freenet.de>
- Fix install path and file format for global rpmlint config file on
  openSUSE_Tumbleweed (bug boo#1190304, boo#1190438)
- Use rpmlint-mini also on Leap 15.x to fix the conflict breakage
- Be more verbose when version in generated xxxConfigVersion.cmake
  files is empty (see https://build.opensuse.org/request/show/915515)
- Sync with mingw32 variant
* Tue Sep 14 2021 Fridrich Strba <fstrba@suse.com>
- Force rpmlint use and avoid using of rpmlint-mini
* Wed Jul 28 2021 Ralf Habacker <ralf.habacker@freenet.de>
- Add provides for bcrypt.dll required by mingw64-gdb 10.2
* Mon Jul 12 2021 Ralf Habacker <ralf.habacker@freenet.de>
- Add provides for ncrypt.dll required by mingw64-gnutls clients
* Mon Jun 14 2021 Callum Farmer <gmbr3@opensuse.org>
- Move RPM macros to %%_rpmmacrodir (boo#1185671)
- Move profile.d entries to %%_distconfdir
- Use %%_fileattrsdir macro
* Thu Nov  5 2020 Ralf Habacker <ralf.habacker@freenet.de>
- Update to 20201105
- Add macro _mingw64_create_macro_links
- Add macro _mingw64_gdb and command line wrapper /usr/bin/mingw64-gdb
- In mingw64-scripts support rpm macro processing according to
  https://rpm.org/user_doc/macros.htm
* Sat Oct 17 2020 Ralf Habacker <ralf.habacker@freenet.de>
- Update to 20201017
- Fix bug not keeping quotes in bash arguments provided to mingw64-scripts.sh
  which is for example required to specify a different cmake generator
* Fri Aug 28 2020 Ralf Habacker <ralf.habacker@freenet.de>
- Fix architecture in generating cmake provides
* Tue Aug 25 2020 Ralf Habacker <ralf.habacker@freenet.de>
- Update to 20200825
- Fix
  * W: non-etc-or-var-file-marked-as-conffile /usr/libexec/rpm/fileattrs/mingw64-cmake.attr
  * W: non-etc-or-var-file-marked-as-conffile /usr/libexec/rpm/mingw64-cmake.prov
  * W: script-without-shebang /usr/libexec/rpm/fileattrs/mingw64-cmake.attr
  * W: non-standard-group Development/Libraries
  * installing mingw64-scripts on Tumbleweed
  * not using present rpmlint config for building this package
* Thu Aug 20 2020 Ralf Habacker <ralf.habacker@freenet.de>
- Add missing Fortran case into macros.mingw64* (boo#1173990)
* Sun Aug 16 2020 Ralf Habacker <ralf.habacker@freenet.de>
- Fix warning about non standard group (boo#1173189)
- Make cmake package support to be more in sync with native package
  * Add mingw64-cmake.prov and mingw64-cmake.attr ported from native
    cmake package to support generating mingw64(cmake:xxx) dependencies
    required by newer KDE Frameworks 5 and other packages.
  * Move out cmake related macros from macros.mingw64 into macros.mingw64-cmake
  * Define macro _mingw64_cmake_build
  * Fix deprecated call to %%make_jobs
  CMake support may be better located in a package named mingw64-cross-cmake
  but need to be used here until the deprecated dependency generator provided
  by this package is converted to sets of *.attr/*.prov files.
- Add additional man languages 'id' and 'uk' used by KDE Frameworks5 packages
* Sun Apr 19 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Process debuginfo in a reproducible way (boo#1041090)
* Wed Dec 18 2019 Martin Koegler <martin.koegler@chello.at>
- Revert -lssp
* Tue Dec 17 2019 Ralf Habacker <ralf.habacker@freenet.de>
- Add -lssp to the link flags, otherwise building of some packages
  (like mingw64-cairo) will be aborted with the error 'undefined
  reference to `__memcpy_chk`'. This library seems not be added by
  gcc 9.2 automatically.
* Mon Nov 25 2019 Ralf Habacker <ralf.habacker@freenet.de>
- add macro _mingw64_ldflags_bootstrap for bootstrap packages
* Mon Nov 25 2019 Ismail Dönmez <idonmez@suse.com>
- Add -fstack-protector to LDFLAGS
* Sun Nov 24 2019 Ralf Habacker <ralf.habacker@freenet.de>
- fix compile errors: undefined reference to `__memcpy_chk`
* Fri Nov 22 2019 Ludwig Nussel <lnussel@suse.de>
- disable default debug package only if the mingw debug macro is used
* Wed Nov 20 2019 Ludwig Nussel <lnussel@suse.de>
- inital package for Factory submission
